@@ -36,12 +36,17 @@ def chebi_fetch(name: str) -> str:
         return ""
     match_string = "Sorry, no results"
     try:
-        code = get(f'https://www.ebi.ac.uk/chebi/advancedSearchFT.do?searchString={name}').text
+        r = get(f'https://www.ebi.ac.uk/chebi/advancedSearchFT.do?searchString={name}')
+        code = r.text
         if match_string in code:
             print("ChEBI fetch failed")
             return ""
-        link = BeautifulSoup(code, 'html.parser').find_all('a', {'target': '_top'})[0]
-        chebi = urlparse(link['href']).query.split(':')[-1]
+        """ List of pages link else direct page """
+        if not r.history:
+            link = BeautifulSoup(code, 'html.parser').find_all('a', {'target': '_top'})[0]
+            chebi = urlparse(link['href']).query.split(':')[-1]
+        else:
+            chebi = urlparse(r.url).query.split(':')[-1]
         return chebi
     except Exception as E:
         print(E)
